#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.2.1
visibility:           public
id:                   hslua-module-zip-1.2.1-6negahFAaN5LikZ0ypdxUe
key:                  hslua-module-zip-1.2.1-6negahFAaN5LikZ0ypdxUe
license:              MIT
copyright:            © 2020-2026 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  05fdd63a58514fb157060a4dbbf545c3
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.2.1-6negahFAaN5LikZ0ypdxUe
depends:
    base-4.18.2.1 hslua-core-2.3.2.1-HnCiZv3qidcGuvBbeqgGBs
    hslua-list-1.1.4-39dm0WZQbgl2OjwmV2zoX9
    hslua-marshalling-2.3.2-4IqhkAnBeEJ3bgQnPylTKM
    hslua-packaging-2.4.1-5f08fLf8mQc6d7onvELW3I text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-HOJElStBDZC4LyBWVIWbJN

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

